==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/ja.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "公開リンク",
    "Photos" : "写真",
    "On This Day" : "この日には",
    "Your memories under your control" : "あなたの思い出はあなたが管理しましょう",
    "All media" : "すべて",
    "Videos" : "動画",
    "Albums" : "アルバム",
    "Collaborative albums" : "共有アルバム",
    "People" : "人間",
    "Folders" : "フォルダー",
    "Favorites" : "お気に入り",
    "On this day" : "この日",
    "Shared with you" : "共有中",
    "Tags" : "タグ",
    "Places" : "場所",
    "Map" : "地図",
    "Photos settings" : "写真の設定",
    "Mark selection as favorite" : "選択項目をお気に入りとしてマーク",
    "Add selection to favorites" : "選択項目をお気に入りに追加",
    "Remove selection from favorites" : "選択項目をお気に入りから削除",
    "Name of the album" : "アルバム名",
    "Location of the album" : "アルバムの場所",
    "Back" : "戻る",
    "Add collaborators" : "共有者に追加",
    "Save" : "保存",
    "Create album" : "アルバムを作成",
    "Add to Album" : "アルバムに追加",
    "Add selection to album {albumName}" : "{albumName} に選択項目を追加する",
    "Shared by" : "共有者",
    "Create a new album." : "新しいアルバムを作成",
    "Create new album" : "新しいアルバムを作成",
    "New album" : "新しいアルバム",
    "_%n item_::_%n photos and videos_" : ["%n の写真とビデオ"],
    "Failed to fetch collaborators list." : "共同作業者リストの取得に失敗しました。",
    "Failed to update album." : "アルバムの更新に失敗しました。",
    "Add people or groups who can edit your album" : "あなたのアルバムを編集できる人またはグループを追加する",
    "Search people or groups" : "人またはグループを検索",
    "No recommendations. Start typing." : "推奨事項はありません。 入力を開始します。",
    "Group" : "グループ",
    "Remove {collaboratorLabel} from the collaborators list" : "コラボレーターリストから {collaboratorLabel} を削除する",
    "Copy the public link" : "公開リンクをコピー",
    "Public link copied!" : "公開リンクをコピーしました！",
    "Copy public link" : "公開リンクをコピー",
    "Delete the public link" : "公開リンクを削除する",
    "Create public link share" : "公開リンク共有の作成",
    "Share via public link" : "公開リンクで共有する",
    "This collection does not exist" : "このコレクションは存在しません",
    "An error occurred" : "エラーが発生しました",
    "No picture for this day" : "この日の画像はありません",
    "Picture taken on this day will show up here." : "この日に撮影された画像はここに表示される。",
    "More photos from this day" : "この日の他の写真",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n 未割り当ての写真"],
    "Favorite" : "お気に入り",
    "Favorite image, open the full size \"{name}\" image" : "お気に入りの画像、フルサイズの \"{name}\" 画像を開く",
    "Open the full size \"{name}\" image" : "画像 \"{name}\" をフルサイズで開く",
    "Select image {imageName}" : "画像 {imageName} を選択",
    "Open the \"{name}\" folder" : "\"{name}\"フォルダーを開く",
    "Back to {folder}" : " {folder} に戻る",
    "Go back" : "戻る",
    "Share this folder" : "このフォルダーを共有する",
    "Dates" : "日付",
    "Jump to specific date in list" : "リスト内の特定の日付にジャンプする",
    "Jump to {date}" : "{date}にジャンプ",
    "Add to {destination}" : "{destination} に追加",
    "The destination folder is owned by {owner}" : "保存先フォルダーの所有者は{owner}です。",
    "There are no photos or videos yet!" : "写真やビデオはまだありません！",
    "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
    "Enable squared photos view" : "写真を矩形での表示を有効化",
    "Delete source directory" : "ソースディレクトリの削除",
    "Pick folder" : "フォルダーを選択",
    "Select a source folder for your media" : "メディアのソースフォルダーを選択してください",
    "All folders" : "全てのフォルダー",
    "Add a Photos source for the timelines" : "タイムラインの写真ソースを追加する",
    "Add folder" : "フォルダーを追加",
    "Select the default upload location for your media" : "メディアのデフォルトのアップロード場所を選択する",
    "Home" : "ホーム",
    "Choose default Photos upload and Albums location" : "デフォルトの写真のアップロードとアルバムの場所を選択する",
    "Choose a different folder" : "別のフォルダーを選択する",
    "View" : "表示",
    "Media folders" : "メディアフォルダー",
    "Choose the folders from where photos and videos are shown." : "写真やビデオを表示するフォルダーを選択します。",
    "Upload folder" : "アップロードフォルダー",
    "Choose the folder where photos and albums are uploaded to." : "写真やアルバムをアップロードするフォルダを選択します。",
    "_%n photo_::_%n photos_" : ["%n 写真"],
    "Unselect all" : "すべて選択解除",
    "Add photos to this album" : "このアルバムに写真を追加",
    "Manage collaborators for this album" : "このアルバムのコラボレーターを管理する",
    "Open actions menu" : "アクションメニューを開く",
    "Edit album details" : "アルバム詳細の編集",
    "Download all files in album" : "アルバム内のすべてのファイルをダウンロードする",
    "Delete album" : "アルバムの削除",
    "Download selected files" : "選択したファイルのダウンロード",
    "Remove selection from album" : "アルバムから選択項目を削除",
    "This album does not have any photos or videos yet!" : "このアルバムにはまだ写真や動画がありません！",
    "Add photos to {albumName}" : "{albumName} に写真を追加",
    "Manage collaborators" : "共同作業者の管理",
    "Save collaborators for this album." : "このアルバムの共同作業者を保存。",
    "Cover photo for album {albumName}" : "アルバム {albumName} のカバー写真",
    "There is no album yet!" : "アルバムはまだありません！",
    "This person could not be found" : "この人物は見つかりませんでした",
    "Rename person" : "名前を変更する",
    "Merge with different person" : "別人と統合",
    "Download selected photos" : "選択した写真をダウンロード",
    "Remove from favorites" : "お気に入りから削除",
    "Remove person" : "人物を削除する",
    "Name of this person" : "この人物の名前",
    "Save." : "保存",
    "Merge person" : "人物をマージする",
    "Move to different person" : "別の人物へ移動",
    "_Move photo to a different person_::_Move photos to a different person_" : ["写真を別の人に移動"],
    "_Remove photo from person_::_Remove photos from person_" : ["人物から写真を削除する"],
    "This might take some time depending on the size of your photo library." : "フォトライブラリーの容量によっては時間がかかる場合があります。",
    "Recognized people will show up here" : "認知された人はここに表示されます",
    "This folder does not exist" : "このフォルダーは存在しません",
    "Loading folders …" : "フォルダを読み込んでいる ...",
    "No photos in here" : "写真がありません",
    "Taken on {date} at {time}" : "{date} の {time} に撮影",
    "This place does not have any photos or videos yet!" : "この場所にはまだ写真も動画もありません！",
    "Add photos to this place" : "この場所に写真を追加",
    "Cover photo for place {placeName}" : "{placeName} の表紙写真",
    "There is no place yet!" : "まだ場所がない！",
    "Cover photo for shared album {albumName}" : "共有アルバム {albumName} の表紙写真",
    "Back to tags overview" : "タグの概要へ戻る",
    "No photos with this tag yet" : "このタグの写真はまだありません",
    "No tags yet" : "まだタグがありません",
    "Photos with tags will show up here" : "タグ付けされた写真がここに表示されます",
    "Popular tags" : "人気のタグ",
    "All tags" : "全てのタグ",
    "One of the source folders does not exist" : "ソースフォルダーの1つが存在しません",
    "Add to album" : "アルバムに追加",
    "Delete selection" : "選択した項目を削除",
    "No photos or videos in here" : "ここには写真も動画もありません",
    "Unassigned faces" : "未割り当ての顔",
    "_%n photos_::_%n photos_" : ["%n 写真"],
    "Failed to fetch collection." : "コレクションの取得に失敗しました。",
    "Failed to fetch collections list." : "コレクションリストの取得に失敗しました。",
    "Failed to fetch faces list." : "顔リストの取得に失敗しました。",
    "Error fetching files" : "ファイル取得エラー",
    "All your media" : "あなたの全てのメディア",
    "Album {title}" : "アルバム {title}",
    "Shared Albums" : "共有アルバム",
    "Shared album {title}" : "共有アルバム {title}",
    "Public album {title}" : "公開アルバム {title}",
    "Tagged photos" : "タグ付けされた写真",
    "Tagged photo {title}" : "タグ付けされた写真 {title}",
    "{title}'s face" : "{title} の顔",
    "{startDate} to {endDate}" : "{startDate} から {endDate}",
    "Details" : "詳細",
    "Failed to rename {oldName} to {faceName}" : "{oldName} から {faceName} への名前の変更に失敗しました",
    "Failed to delete {faceName}" : "{faceName} の削除に失敗しました",
    "Failed to delete {fileId}" : "{fileId} の削除に失敗しました",
    "Failed to delete {fileName}" : "{fileName} の削除に失敗しました",
    "Failed to set favorite state for {fileId}" : "{fileId} のお気に入り状態の設定に失敗しました",
    "Failed to set favorite state for {fileName}" : "{fileName} のお気に入り状態の設定に失敗しました",
    "Could not load photos folder" : "写真フォルダを読み込めませんでした",
    "One of the source folders does not exists" : "ソースフォルダーの1つが存在しません",
    "Add" : "追加"
},
"nplurals=1; plural=0;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/ja.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "公開リンク",
    "Photos" : "写真",
    "On This Day" : "この日には",
    "Your memories under your control" : "あなたの思い出はあなたが管理しましょう",
    "All media" : "すべて",
    "Videos" : "動画",
    "Albums" : "アルバム",
    "Collaborative albums" : "共有アルバム",
    "People" : "人間",
    "Folders" : "フォルダー",
    "Favorites" : "お気に入り",
    "On this day" : "この日",
    "Shared with you" : "共有中",
    "Tags" : "タグ",
    "Places" : "場所",
    "Map" : "地図",
    "Photos settings" : "写真の設定",
    "Mark selection as favorite" : "選択項目をお気に入りとしてマーク",
    "Add selection to favorites" : "選択項目をお気に入りに追加",
    "Remove selection from favorites" : "選択項目をお気に入りから削除",
    "This name is already in use." : "この名前は既に使用されています。",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\"はファイル名には使用できません。",
    "Invalid filename." : "無効なファイル名。",
    "Name of the album" : "アルバム名",
    "Location of the album" : "アルバムの場所",
    "Back" : "戻る",
    "Add collaborators" : "共有者に追加",
    "Save" : "保存",
    "Create album" : "アルバムを作成",
    "Add to Album" : "アルバムに追加",
    "Add selection to album {albumName}" : "{albumName} に選択項目を追加する",
    "Shared by" : "共有者",
    "Create a new album." : "新しいアルバムを作成",
    "Create new album" : "新しいアルバムを作成",
    "New album" : "新しいアルバム",
    "_%n item_::_%n photos and videos_" : ["%n の写真とビデオ"],
    "Failed to fetch collaborators list." : "共同作業者リストの取得に失敗しました。",
    "Failed to update album." : "アルバムの更新に失敗しました。",
    "Add people or groups who can edit your album" : "あなたのアルバムを編集できる人またはグループを追加する",
    "Search people or groups" : "人またはグループを検索",
    "No recommendations. Start typing." : "推奨事項はありません。 入力を開始します。",
    "Copy the public link" : "公開リンクをコピー",
    "Public link copied!" : "公開リンクをコピーしました！",
    "Copy public link" : "公開リンクをコピー",
    "Delete the public link" : "公開リンクを削除する",
    "Create public link share" : "公開リンク共有の作成",
    "Share via public link" : "公開リンクで共有する",
    "This collection does not exist" : "このコレクションは存在しません",
    "An error occurred" : "エラーが発生しました",
    "No picture for this day" : "この日の画像はありません",
    "Picture taken on this day will show up here." : "この日に撮影された画像はここに表示される。",
    "More photos from this day" : "この日の他の写真",
    "_%n photos_::_%n photos_" : ["%n 写真"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n 未割り当ての写真"],
    "Favorite" : "お気に入り",
    "Favorite image, open the full size \"{name}\" image" : "お気に入りの画像、フルサイズの \"{name}\" 画像を開く",
    "Open the full size \"{name}\" image" : "画像 \"{name}\" をフルサイズで開く",
    "Select image {imageName}" : "画像 {imageName} を選択",
    "Open the \"{name}\" folder" : "\"{name}\"フォルダーを開く",
    "Go back" : "戻る",
    "Select a custom date range" : "カスタム日付範囲の選択",
    "Select a date range" : "日付範囲を選択",
    "Date range" : "日付範囲",
    "Select filters" : "フィルターを選択",
    "Dates" : "日付",
    "Jump to specific date in list" : "リスト内の特定の日付にジャンプする",
    "Jump to {date}" : "{date}にジャンプ",
    "Add to {destination}" : "{destination} に追加",
    "The destination folder is owned by {owner}" : "保存先フォルダーの所有者は{owner}です。",
    "There are no photos or videos yet!" : "写真やビデオはまだありません！",
    "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
    "Squared photos view" : "正方形の写真ビュー",
    "Delete source directory" : "ソースディレクトリの削除",
    "Pick folder" : "フォルダーを選択",
    "Select a source folder for your media" : "メディアのソースフォルダーを選択してください",
    "Media folders" : "メディアフォルダー",
    "Choose the folders from where photos and videos are shown." : "写真やビデオを表示するフォルダーを選択します。",
    "All folders" : "全てのフォルダー",
    "Add a Photos source for the timelines" : "タイムラインの写真ソースを追加する",
    "Add folder" : "フォルダーを追加",
    "Home" : "ホーム",
    "Select the default upload location for your media" : "メディアのデフォルトのアップロード場所を選択する",
    "Upload folder" : "アップロードフォルダー",
    "General" : "一般",
    "_%n photo_::_%n photos_" : ["%n 写真"],
    "Unselect all" : "すべて選択解除",
    "Add photos to this album" : "このアルバムに写真を追加",
    "Manage collaborators for this album" : "このアルバムのコラボレーターを管理する",
    "Open actions menu" : "アクションメニューを開く",
    "Edit album details" : "アルバム詳細の編集",
    "Download all files in album" : "アルバム内のすべてのファイルをダウンロードする",
    "Delete album" : "アルバムの削除",
    "Download selected files" : "選択したファイルのダウンロード",
    "Remove selection from album" : "アルバムから選択項目を削除",
    "This album does not have any photos or videos yet!" : "このアルバムにはまだ写真や動画がありません！",
    "Add photos to {albumName}" : "{albumName} に写真を追加",
    "Manage collaborators" : "共同作業者の管理",
    "Save collaborators for this album." : "このアルバムの共同作業者を保存。",
    "Cover photo for album {albumName}" : "アルバム {albumName} のカバー写真",
    "There is no album yet!" : "アルバムはまだありません！",
    "This person could not be found" : "この人物は見つかりませんでした",
    "Rename person" : "名前を変更する",
    "Merge with different person" : "別人と統合",
    "Download selected photos" : "選択した写真をダウンロード",
    "Remove from favorites" : "お気に入りから削除",
    "Remove person" : "人物を削除する",
    "Name of this person" : "この人物の名前",
    "Save." : "保存",
    "Merge person" : "人物をマージする",
    "Move to different person" : "別の人物へ移動",
    "_Move photo to a different person_::_Move photos to a different person_" : ["写真を別の人に移動"],
    "_Remove photo from person_::_Remove photos from person_" : ["人物から写真を削除する"],
    "This might take some time depending on the size of your photo library." : "フォトライブラリーの容量によっては時間がかかる場合があります。",
    "Recognized people will show up here" : "認知された人はここに表示されます",
    "This folder does not exist" : "このフォルダーは存在しません",
    "Loading folders…" : "フォルダーの読み込み中…",
    "No photos in here" : "写真がありません",
    "Taken on {date} at {time}" : "{date} の {time} に撮影",
    "This place does not have any photos or videos yet!" : "この場所にはまだ写真も動画もありません！",
    "Add photos to this place" : "この場所に写真を追加",
    "Cover photo for place {placeName}" : "{placeName} の表紙写真",
    "There is no place yet!" : "まだ場所がない！",
    "Cover photo for shared album {albumName}" : "共有アルバム {albumName} の表紙写真",
    "Back to tags overview" : "タグの概要へ戻る",
    "No photos with this tag yet" : "このタグの写真はまだありません",
    "No tags yet" : "まだタグがありません",
    "Photos with tags will show up here" : "タグ付けされた写真がここに表示されます",
    "Popular tags" : "人気のタグ",
    "All tags" : "全てのタグ",
    "Create new album from filters" : "フィルターから新しいアルバムを作成する",
    "One of the source folders does not exist" : "ソースフォルダーの1つが存在しません",
    "Add to album" : "アルバムに追加",
    "Delete selection" : "選択した項目を削除",
    "No photos or videos in here" : "ここには写真も動画もありません",
    "Unassigned faces" : "未割り当ての顔",
    "Failed to fetch collection." : "コレクションの取得に失敗しました。",
    "Failed to fetch collections list." : "コレクションリストの取得に失敗しました。",
    "Failed to fetch faces list." : "顔リストの取得に失敗しました。",
    "Error fetching files" : "ファイル取得エラー",
    "All your media" : "あなたの全てのメディア",
    "Album {title}" : "アルバム {title}",
    "Shared Albums" : "共有アルバム",
    "Shared album {title}" : "共有アルバム {title}",
    "Public album {title}" : "公開アルバム {title}",
    "Tagged photos" : "タグ付けされた写真",
    "Tagged photo {title}" : "タグ付けされた写真 {title}",
    "{title}'s face" : "{title} の顔",
    "Last week" : "先週",
    "Last Month" : "先月",
    "Custom…" : "カスタム…",
    "{startDate} to {endDate}" : "{startDate} から {endDate}",
    "Details" : "詳細",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "{fileBaseName}をコレクション{collectionFileName}に追加できませんでした",
    "Failed to delete {fileBaseName}" : "{fileBaseName} の削除に失敗しました",
    "Failed to create {collectionFileName}" : "{collectionFileName} の作成に失敗しました",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "{currentCollectionFileName} から {newCollectionFileName} への名前の変更に失敗しました",
    "Failed to update properties of {collectionFileName} with {properties}" : "{collectionFileName}のプロパティを{properties}で更新できませんでした",
    "Delete collection" : "コレクションを削除",
    "Leave shared album" : "共有アルバムを離れる",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "本当に{collectionName}を削除しますか？この操作は元に戻すことができません。",
    "Failed to delete {collectionFileName}" : "{collectionFileName} の削除に失敗しました",
    "Cancel" : "キャンセル",
    "Confirm" : "承認",
    "Failed to move {fileBaseName} to person {faceName}" : "{fileBaseName}を{faceName}への移動に失敗しました",
    "Failed to remove {fileBaseName}" : "{fileBaseName}の削除に失敗しました",
    "Failed to rename {oldName} to {faceName}" : "{oldName} から {faceName} への名前の変更に失敗しました",
    "Failed to delete {faceName}" : "{faceName} の削除に失敗しました",
    "Failed to delete {fileId}" : "{fileId} の削除に失敗しました",
    "Failed to delete {fileName}" : "{fileName} の削除に失敗しました",
    "Failed to set favorite state for {fileId}" : "{fileId} のお気に入り状態の設定に失敗しました",
    "Failed to set favorite state for {fileName}" : "{fileName} のお気に入り状態の設定に失敗しました",
    "Could not load photos folder" : "写真フォルダを読み込めませんでした",
    "Group" : "グループ",
    "Remove {collaboratorLabel} from the collaborators list" : "コラボレーターリストから {collaboratorLabel} を削除する",
    "Back to {folder}" : " {folder} に戻る",
    "Share this folder" : "このフォルダーを共有する",
    "Enable squared photos view" : "写真を矩形での表示を有効化",
    "Choose default Photos upload and Albums location" : "デフォルトの写真のアップロードとアルバムの場所を選択する",
    "Choose a different folder" : "別のフォルダーを選択する",
    "View" : "表示",
    "Choose the folder where photos and albums are uploaded to." : "写真やアルバムをアップロードするフォルダを選択します。",
    "Loading folders …" : "フォルダを読み込んでいる ...",
    "Add" : "追加",
    "Loading folders …" : "フォルダを読み込み中…"
},
"nplurals=1; plural=0;");
